@@ -11,6 +11,7 @@ if __name__ == '__main__':
     service = ConfigurationService(watch=True)
     service.registerModel('example/model')
     service.loadConfiguration('example/sample_config/all-in-one.ini')
+    service.start()
 
     # keep artificially the main thread alive forever
     while True:
@@ -23,7 +24,7 @@ if __name__ == '__main__':
             print 'stop monitoring...'
             # stop monitoring
             if service.notifier:
-                service.notifier.stop()
+                service.shutdown()
             print 'done'
             break
         except Exception, err:
