@@ -18,8 +18,7 @@ from unittest import TestCase, TestSuite, makeSuite
 from haufe.hrs.configuration.service import ConfigurationService
 from haufe.hrs.configuration.interfaces import IConfigurationService
 from haufe.hrs.configuration.util import DEFAULT_MARKER
-
-dirname = os.path.dirname(os.path.abspath(__file__))
+from pkg_resources import resource_filename
 
 class ServiceTests(TestCase):
 
@@ -31,9 +30,9 @@ class ServiceTests(TestCase):
 
     def testService(self):
         service = self._makeOne()
-        service.registerModel(os.path.join(dirname, 'model', 'cms.ini'))
-        service.registerModel(os.path.join(dirname, 'model', 'toolbox.ini'))
-        service.loadConfiguration(os.path.join(dirname, 'example-config.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration','tests/model/cms.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration','tests/model/toolbox.ini'))
+        service.loadConfiguration(resource_filename('haufe.hrs.configuration','tests/example-config.ini'))
 
         self.assertEqual(service.get('path', 'cms'), '/a/b/c') 
         self.assertEqual(service.get('checkout_path', 'cms'), '/foo/bar')
@@ -42,9 +41,9 @@ class ServiceTests(TestCase):
 
     def testGetConfiguration(self):
         service = self._makeOne()
-        service.registerModel(os.path.join(dirname, 'model', 'cms.ini'))
-        service.registerModel(os.path.join(dirname, 'model', 'toolbox.ini'))
-        service.loadConfiguration(os.path.join(dirname, 'example-config.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration','tests/model/cms.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration','tests/model/toolbox.ini'))
+        service.loadConfiguration(resource_filename('haufe.hrs.configuration','tests/example-config.ini'))
         got = service.getConfiguration()
         expected = {'cms.path' : '/a/b/c',
                     'cms.checkout_path' : '/foo/bar',
@@ -59,18 +58,18 @@ class ServiceTests(TestCase):
 
     def testGetConfigurationForDomain(self):
         service = self._makeOne()
-        service.registerModel(os.path.join(dirname, 'model', 'cms.ini'))
-        service.registerModel(os.path.join(dirname, 'model', 'toolbox.ini'))
-        service.loadConfiguration(os.path.join(dirname, 'example-config.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration', 'tests/model/cms.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration', 'tests/model/toolbox.ini'))
+        service.loadConfiguration(resource_filename('haufe.hrs.configuration', 'tests/example-config.ini'))
         got = service.getConfigurationForDomain('toolbox')
         expected = {'toolbox.active' : 0}
         self.assertEqual(got, expected)
 
     def testServiceAndReload(self):
         service = self._makeOne()
-        service.registerModel(os.path.join(dirname, 'model', 'cms.ini'))
-        service.registerModel(os.path.join(dirname, 'model', 'toolbox.ini'))
-        service.loadConfiguration(os.path.join(dirname, 'example-config.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration', 'tests/model/cms.ini'))
+        service.registerModel(resource_filename('haufe.hrs.configuration', 'tests/model/toolbox.ini'))
+        service.loadConfiguration(resource_filename('haufe.hrs.configuration', 'tests/example-config.ini'))
         self.assertEqual(service.get('path', 'cms'), '/a/b/c')                
         service.reload()
         self.assertEqual(service.get('path', 'cms'), '/a/b/c') 
